@@ -1,14 +1,14 @@
 #A* -------------------------------------------------------------------
 #B* This file contains source code for the PyMOL computer program
-#C* Copyright (c) Schrodinger, LLC. 
+#C* Copyright (c) Schrodinger, LLC.
 #D* -------------------------------------------------------------------
 #E* It is unlawful to modify or remove this copyright notice.
 #F* -------------------------------------------------------------------
-#G* Please see the accompanying LICENSE file for further information. 
+#G* Please see the accompanying LICENSE file for further information.
 #H* -------------------------------------------------------------------
 #I* Additional authors of this source file include:
-#-* 
-#-* 
+#-*
+#-*
 #-*
 #Z* -------------------------------------------------------------------
 
@@ -27,7 +27,9 @@ Options
 
   --help    display this help and exit
   --version display PyMOL version and exit
-  --retina  use retina resolution (Experimental, MacPyMOL only)
+  --gldebug use glDebugMessageCallback for GL debugging
+  --testing run pymol testing
+  --diagnostics dump system diagnostics
 
   -1        config_mouse one_button
   -2        config_mouse two_button
@@ -64,7 +66,7 @@ Options
   -m        INTERNAL - do not use (mac external GUI)
   -M        force mono
   -n        INTERNAL - do not use (incentive_product=1)
-  -N name   UNSUPPORTED - external gui type (default: pmg_tk) (same as -w)
+  -N name   UNSUPPORTED - external gui type (pmg_qt or pmg_tk) (same as -w)
   -o        disable security protections
   -O N      sphere_mode=N
   -p        read commands from STDIN
@@ -79,9 +81,9 @@ Options
   -T name   UNSUPPORTED - Tcl/Tk GUI skin
   -u file   resume log file (execute existing content and append new log output)
   -U        UNSUPPORTED reuse the helper application
-  -v        UNUSED
+  -v        use openvr stub instead of a real hardware
   -V N      external GUI window height in pixels
-  -w name   UNSUPPORTED - external gui type (default: pmg_tk) (same as -N)
+  -w name   UNSUPPORTED - external gui type (pmg_qt or pmg_tk) (same as -N)
   -W N      window width in pixels
   -x        no external gui
   -X N      window x position on screen
@@ -109,7 +111,7 @@ helptext2 = '''
 Mail bug reports to https://lists.sourceforge.net/lists/listinfo/pymol-users
 '''
 
-if __name__=='pymol.invocation':
+if True:
 
     import copy
     import re
@@ -117,19 +119,19 @@ if __name__=='pymol.invocation':
     import glob
     import sys
     import traceback
-    
+
     pymolrc_pat1 = '.pymolrc*'
     pymolrc_pat2 = 'pymolrc*'
-    
+
     ros_pat = 'run_on_startup*'
-    
+
     class generic:
         pass
 
     global_options = generic();
 
     options = global_options
-    
+
     options.deferred = []
     options.no_gui = 0
     options.internal_gui = 1
@@ -144,7 +146,7 @@ if __name__=='pymol.invocation':
     options.win_x = 640
     options.win_y = 480
     options.win_xy_set = False
-    options.win_px = 4 
+    options.win_px = 4
     options.sigint_handler = 1 # terminate on Ctrl-C?
     options.reuse_helper = 0
     options.auto_reinitialize = 0
@@ -165,6 +167,11 @@ if __name__=='pymol.invocation':
     options.plugins = 2
     options.exit_on_error = 0
     options.pymolrc = None
+    options.no_spacenav = 0
+    options.launch_status = 0
+    options.gldebug = 0
+    options.testing = 0
+    options.openvr_stub = False
 
     options.win_py = { 'irix':240,
                        'darwin': 214, # hmm...need to set to 192 for Leopard?...
@@ -179,12 +186,12 @@ if __name__=='pymol.invocation':
     options.rpcServer = 0
     # end
     options.security = 1
-    
+
     script_re = re.compile(r"pymolrc$|\.pml$|\.PML$|\.p1m$|\.P1M$")
     py_re = re.compile(r"\.py$|\.pym$|\.PY$|\.PYM$")
 
     def get_pwg_options(filename):
-        for line in open(filename, 'rU'):
+        for line in open(filename, 'r'):
             a = line.split()
             if not a or a[0].startswith('#'):
                 continue
@@ -225,7 +232,7 @@ if __name__=='pymol.invocation':
             if py_re.search(a):
                 first.append(a) # preceeding "_ " cloaks
             elif script_re.search(a):
-                second.append(a) # preceeding "_ " cloaks 
+                second.append(a) # preceeding "_ " cloaks
 
         first.sort()
         second.sort()
@@ -236,8 +243,8 @@ if __name__=='pymol.invocation':
             global _argv
             _argv = copy.deepcopy(argv) # pymol.invocation._argv
             global global_options
-            if options == None:
-                if _pymol==None:
+            if options is None:
+                if _pymol is None:
                     options = global_options
                 else:
                     options = _pymol.invocation.options
@@ -270,9 +277,21 @@ if __name__=='pymol.invocation':
                                 print('  (no pymolrc file found)')
                             print(helptext2)
                         sys.exit()
+                    elif a == "--retina":
+                        print("Warning: --retina option has been removed")
+                    elif a == "--nospnav":
+                        print(' Warning: --nospnav not available in Open-Source PyMOL')
+                    elif a == "--gldebug":
+                        options.gldebug = 1
+                    elif a == "--testing":
+                        options.testing = 1
+                    elif a == "--diagnostics":
+                        # same as: -cd diagnostics
+                        options.no_gui=1
+                        options.deferred.append("_do_diagnostics")
                     else:
                         # double hypen signals end of PyMOL arguments
-                        if python_script == None:
+                        if python_script is None:
                             python_script = argv[0]
                         rev_av = copy.deepcopy(av)
                         rev_av.reverse()
@@ -285,7 +304,7 @@ if __name__=='pymol.invocation':
                 if ("A" in a) or ("a" in a): # application configuration
                     new_args = []
                     # ====== mode 1 - simple viewer window ======
-                    if a[2:3] == "1": 
+                    if a[2:3] == "1":
                         if 'A1' not in once_dict:
                             once_dict['A1'] = 1
                             new_args = ["-qxiF",
@@ -294,7 +313,7 @@ if __name__=='pymol.invocation':
                                 ]
                     # ====== mode 2 - not available -- clashes with -2 =======
                     # ====== mode 3 - internal GUI only no splash ======
-                    if a[2:3] == "3": 
+                    if a[2:3] == "3":
                         if 'A3' not in once_dict:
                             once_dict['A3'] = 1
                             new_args = ["-qx",
@@ -310,7 +329,7 @@ if __name__=='pymol.invocation':
                                 "-Y","100",
                                 ]
                     # ====== mode 5 - mode 5 helper application ======
-                    if a[2:3] == "5": 
+                    if a[2:3] == "5":
                         if 'A5' not in once_dict:
                             once_dict['A5'] = 1
                             new_args = ["-QxiICUF",
@@ -318,7 +337,7 @@ if __name__=='pymol.invocation':
                                 "-Y","100",
                                 ]
                     # ====== mode 6 - mode 6 presentation (no GUI) ======
-                    if a[2:3] == "6": 
+                    if a[2:3] == "6":
                         if 'A6' not in once_dict:
                             once_dict['A6'] = 1
                             new_args = ["-qxieICUPF",
@@ -343,7 +362,7 @@ if __name__=='pymol.invocation':
                 if "E" in a:
                     options.multisample = int(av.pop())
                 if "P" in a:
-                    options.presentation = 1 
+                    options.presentation = 1
                 if "W" in a:
                     options.win_x = int(av.pop())
                     options.win_xy_set = True
@@ -358,6 +377,8 @@ if __name__=='pymol.invocation':
                     options.win_py = int(av.pop())
                 if "D" in a:
                     options.defer_builds_mode = int(av.pop())
+                if "v" in a:
+                    options.openvr_stub = True
                 if "V" in a:
                     options.ext_y = int(av.pop())
                 if "N" in a: # external gui name...
@@ -368,7 +389,7 @@ if __name__=='pymol.invocation':
                     options.incentive_product = 1
                 if "t" in a: # type of stereo to use
                     options.stereo_mode = int(av.pop())
-                if "T" in a: # what skin to use? 
+                if "T" in a: # what skin to use?
                     options.skin = str(av.pop())
                 if "w" in a: # what gui to use
                     options.gui = str(av.pop())
@@ -391,8 +412,8 @@ if __name__=='pymol.invocation':
                                 options.win_py = 216
                         else:
                             options.external_gui = 2
-                            options.win_py = 184 
-                    
+                            options.win_py = 184
+
                     if "e" in a:
                         options.full_screen = 1
                     if "G" in a: # Game mode (reqd for Mac stereo)
@@ -403,7 +424,7 @@ if __name__=='pymol.invocation':
                         options.force_stereo = 1
                         if options.stereo_mode == 0:
                             options.stereo_mode = 1  # quadbuffer
-                        if sys.platform=='darwin': 
+                        if sys.platform=='darwin':
                             options.deferred.append(
                               "_do__ set stereo_double_pump_mono,1,quiet=1")
                     if "M" in a: # Force mono on stereo hardware (all)
@@ -457,7 +478,7 @@ if __name__=='pymol.invocation':
                             options.deferred.append("_do__ cmd.get_wizard().ray_trace1()")
                         if a[2:]=='2':
                             options.deferred.append("_do__ cmd.get_wizard().ray_trace2()")
-                        
+
                     if "p" in a:
                         options.read_stdin = 1
                     if "K" in a:
@@ -482,7 +503,7 @@ if __name__=='pymol.invocation':
             elif not restricted:
                 suffix = a[-4:].lower().split('.')[-1]
                 if suffix == "p5m":
-                    # mode 5 helper application 
+                    # mode 5 helper application
                     av.append("-A5")
                 elif suffix == "psw":
                     # presentation mode
@@ -498,7 +519,7 @@ if __name__=='pymol.invocation':
                         traceback.print_exc()
                 options.deferred.append(a)
                 loaded_something = 1
-        if pymolrc != None:
+        if pymolrc is not None:
             options.deferred = [('_do__ @' + a) if script_re.search(a) else a
                     for a in pymolrc] + options.deferred
             options.pymolrc = pymolrc
