@@ -1,39 +1,39 @@
 #A* -------------------------------------------------------------------
 #B* This file contains source code for the PyMOL computer program
-#C* Copyright (c) Schrodinger, LLC. 
+#C* Copyright (c) Schrodinger, LLC.
 #D* -------------------------------------------------------------------
 #E* It is unlawful to modify or remove this copyright notice.
 #F* -------------------------------------------------------------------
-#G* Please see the accompanying LICENSE file for further information. 
+#G* Please see the accompanying LICENSE file for further information.
 #H* -------------------------------------------------------------------
 #I* Additional authors of this source file include:
-#-* 
-#-* 
+#-*
+#-*
 #-*
 #Z* -------------------------------------------------------------------
 
 from __future__ import print_function
 
-if __name__=='pymol.setting':
-    
+# must match layer1/Setting.h
+cSetting_tuple = -1
+cSetting_blank = 0
+cSetting_boolean = 1
+cSetting_int = 2
+cSetting_float = 3
+cSetting_float3 = 4
+cSetting_color = 5
+cSetting_string = 6
+
+if True:
+
     import traceback
-    import string
-    import types
     from . import selector
     from .shortcut import Shortcut
     cmd = __import__("sys").modules["pymol.cmd"]
     from .cmd import _cmd,lock,lock_attempt,unlock,QuietException, \
           is_string, \
           _feedback,fb_module,fb_mask, \
-          DEFAULT_ERROR, DEFAULT_SUCCESS, _raising, is_ok, is_error        
-    import re
-    
-    boolean_type = 1
-    int_type     = 2
-    float_type   = 3
-    float3_type  = 4
-
-    self = cmd
+          DEFAULT_ERROR, DEFAULT_SUCCESS, _raising, is_ok, is_error
 
     # name -> index mapping
     index_dict = _cmd.get_setting_indices()
@@ -47,11 +47,6 @@ if __name__=='pymol.setting':
     # legacy
     index_dict['ray_shadows'] =     index_dict['ray_shadow']
 
-    # legacy, in case someone used that in a script
-    class SettingIndex:
-        def __getattr__(self, name):
-            return index_dict[name]
-
     boolean_dict = {
         "true" : 1,
         "false": 0,
@@ -86,29 +81,29 @@ if __name__=='pymol.setting':
         return name_list
 
     def _validate_value(type, value):
-        if type==1: # boolean (also support non-zero float for truth)
+        if type == cSetting_boolean:  # (also support non-zero float for truth)
             try: # number, non-zero, then interpret as TRUE
                 return 1 if float(value) else 0
             except:
                 pass
             return boolean_dict[boolean_sc.auto_err(str(value), "boolean")]
-        if type < 4:
+        if type in (cSetting_int, cSetting_float):
             if is_string(value) and boolean_sc.has_key(value):
                 value = boolean_dict[boolean_sc.auto_err(str(value), "boolean")]
-            if type == 2:
+            if type == cSetting_int:
                 return int(value)
             return float(value)
-        if type==4: # float3 - some legacy handling req.
+        if type == cSetting_float3:  # some legacy handling req.
             if not is_string(value):
                 v = value
             elif ',' in value:
-                v = eval(value)
+                v = cmd.safe_eval(value)
             else:
                 v = value.split()
             return (float(v[0]), float(v[1]), float(v[2]))
-        if type==5: # color
+        if type == cSetting_color:
             return str(value)
-        if type==6: # string
+        if type == cSetting_string:
             v = str(value)
             # strip outermost quotes (cheesy approach)
             if len(v) > 1 and v[0] == v[-1] and v[0] in ('"', "'"):
@@ -199,13 +194,13 @@ PYMOL API
                     raise _self.pymol.CmdException("invalid value: %s" % repr(value))
             finally:
                 _self.unlock(r,_self)
-        if _self._raising(r,_self): raise QuietException            
+        if _self._raising(r,_self): raise QuietException
         return r
 
-        
+
     def set(name, value=1, selection='', state=0, updates=1, log=0,
             quiet=1,_self=cmd):
-        
+
         '''
 DESCRIPTION
 
@@ -305,7 +300,7 @@ SEE ALSO
                     raise _self.pymol.CmdException("invalid value: %s" % repr(value))
             finally:
                 _self.unlock(r,_self)
-        if _self._raising(r,_self): raise QuietException            
+        if _self._raising(r,_self): raise QuietException
         return r
 
     def unset(name, selection='', state=0, updates=1, log=0, quiet=1, _self=cmd):
@@ -365,7 +360,7 @@ SEE ALSO
                 finally:
                     _self.unlock(r,_self)
         return r
-    
+
     def unset_bond(name,selection1,selection2=None,state=0,updates=1,log=0,quiet=1,_self=cmd):
         '''
 DESCRIPTION
@@ -399,31 +394,11 @@ USAGE
                     print("Error: unable to unset setting value.")
             finally:
                 _self.unlock(r,_self)
-        if _self._raising(r,_self): raise QuietException            
+        if _self._raising(r,_self): raise QuietException
         return r
 
     def get_setting(name,object='',state=0,_self=cmd): # INTERNAL
-        r = DEFAULT_ERROR
-        i = _get_index(name)
-        try:
-            _self.lock(_self)
-            r = _cmd.get_setting_tuple(_self._COb,i,str(object),int(state)-1)
-            typ = r[0]
-            if typ<3: # boolean, int
-                value = int(r[1][0])
-            elif typ<4: # float
-                value = r[1][0]
-            elif typ<5: # vector
-                value = r[1]
-            else:
-                value = r[1] # color or string
-        finally:
-            _self.unlock(r,_self)
-        if is_ok(r):
-            return value
-        elif _self._raising(r,_self):
-            raise QuietException                     
-        return r
+        return get_setting_tuple_new(name, object, state, _self)[1]
 
     def get(name, selection='', state=0, quiet=1, _self=cmd):
         '''
@@ -462,16 +437,11 @@ SEE ALSO
     set, set_bond, get_bond
 
     '''
-        
-        r = DEFAULT_ERROR
+
         state = int(state)
         i = _get_index(name)
-        try:
-            _self.lock(_self)
-            r = _cmd.get_setting_text(_self._COb,i,str(selection),state-1)
-        finally:
-            _self.unlock(r,_self)
-        if is_ok(r) and (r!=None):
+        r = get_setting_text(i, str(selection), state, _self)
+        if is_ok(r) and (r is not None):
             if not int(quiet):
                 name = name_dict.get(i, name)
                 r_str = str(r)
@@ -483,69 +453,39 @@ SEE ALSO
                     print(" get: %s = %s in object %s"%(name,r_str,selection))
                 else:
                     print(" get: %s = %s in object %s state %d"%(name,r_str,selection,state))
-        if _self._raising(r,_self): raise QuietException
         return r
-    
+
     def get_setting_tuple_new(name,object='',state=0,_self=cmd): # INTERNAL
-        r = DEFAULT_ERROR
         i = _get_index(name)
-        try:
-            _self.lock(_self)
-            r = _cmd.get_setting_tuple(_self._COb,i,str(object),int(state)-1)
-        finally:
-            _self.unlock(r,_self)
-        if _self._raising(r,_self): raise QuietException
-        return r
+        with _self.lockcm:
+            return _cmd.get_setting_of_type(_self._COb, i, str(object), int(state) - 1, cSetting_tuple)
 
     def get_setting_tuple(name,object='',state=0,_self=cmd): # INTERNAL
         r = get_setting_tuple_new(name, object, state, _self)
-        if r[0] != 4:
+        if r[0] != cSetting_float3:
             # legacy API
             r = (r[0], (r[1],))
         return r
-    
+
     def get_setting_boolean(name,object='',state=0,_self=cmd): # INTERNAL
-        r = DEFAULT_ERROR
         i = _get_index(name)
-        try:
-            _self.lock(_self)
-            r = _cmd.get_setting_of_type(_self._COb,i,str(object),int(state)-1,1)
-        finally:
-            _self.unlock(r,_self)
-        if _self._raising(r,_self): raise QuietException
-        return r
-    
+        with _self.lockcm:
+            return _cmd.get_setting_of_type(_self._COb, i, str(object), int(state) - 1, cSetting_boolean)
+
     def get_setting_int(name,object='',state=0,_self=cmd): # INTERNAL
-        r = DEFAULT_ERROR
         i = _get_index(name)
-        try:
-            _self.lock(_self)
-            r = _cmd.get_setting_of_type(_self._COb,i,str(object),int(state)-1,2)
-        finally:
-            _self.unlock(r,_self)
-        return r
-    
+        with _self.lockcm:
+            return _cmd.get_setting_of_type(_self._COb, i, str(object), int(state) - 1, cSetting_int)
+
     def get_setting_float(name,object='',state=0,_self=cmd): # INTERNAL
-        r = DEFAULT_ERROR
         i = _get_index(name)
-        try:
-            _self.lock(_self)
-            r = _cmd.get_setting_of_type(_self._COb,i,str(object),int(state)-1,3)
-        finally:
-            _self.unlock(r,_self)
-        if _self._raising(r,_self): raise QuietException
-        return r
+        with _self.lockcm:
+            return _cmd.get_setting_of_type(_self._COb, i, str(object), int(state) - 1, cSetting_float)
 
     def get_setting_text(name,object='',state=0,_self=cmd):  # INTERNAL
-        r = DEFAULT_ERROR
         i = _get_index(name)
-        try:
-            _self.lock(_self)
-            r = _cmd.get_setting_text(_self._COb,i,str(object),int(state)-1)
-        finally:
-            _self.unlock(r,_self)
-        if _self._raising(r,_self): raise QuietException
-        return r
+        with _self.lockcm:
+            return _cmd.get_setting_of_type(_self._COb, i, str(object), int(state) - 1, cSetting_string)
 
     def get_setting_updates(object='', state=0, _self=cmd): # INTERNAL
         r = []
@@ -624,7 +564,7 @@ PYMOL API
                     raise QuietException
             finally:
                 _self.unlock(r,_self)
-        if _self._raising(r,_self): raise QuietException            
+        if _self._raising(r,_self): raise QuietException
         if not quiet:
             name = name_dict.get(index, name)
             suffix = ' state %d' % state if state > 0 else ''
@@ -645,7 +585,7 @@ DESCRIPTION
 
     Note: Does currently NOT unset atom-state level settings. Check for
     atom-state level settings with:
-    PyMOL> iterate_state 1, *, print list(s)
+    PyMOL> iterate_state 1, *, print(list(s))
     Unset e.g. atom-state level "label_screen_point" (index 728) with:
     PyMOL> alter_state 1, *, del s[728]
 
